@@ -521,6 +521,29 @@ extern Matrix1D<QList<ActivitiesPairOfMutuallyExclusiveTimeSlots_item*>> apomets
 bool computeActivitiesPairOfMutuallyExclusiveTimeSlots(QWidget* parent);
 
 
+//BEGIN teacher(s) occupy max sets of time slots from selection
+extern bool haveTeachersOccupyMaxSetsOfTimeSlotsFromSelection;
+
+extern Matrix1D<QList<double>> teachersOccupyMaxSetsOfTimeSlotsFromSelectionPercentages;
+extern Matrix1D<QList<int>> teachersOccupyMaxSetsOfTimeSlotsFromSelectionMaxOccupiedSets;
+extern Matrix1D<QList<QList<QSet<int>>>> teachersOccupyMaxSetsOfTimeSlotsFromSelectionListOfSets;
+extern Matrix1D<QList<QList<QList<int>>>> teachersOccupyMaxSetsOfTimeSlotsFromSelectionListOfLists;
+
+bool computeTeachersOccupyMaxSetsOfTimeSlotsFromSelection(QWidget* parent);
+//END   teacher(s) occupy max sets of time slots from selection
+
+//BEGIN students (set) occupy max sets of time slots from selection
+extern bool haveStudentsOccupyMaxSetsOfTimeSlotsFromSelection;
+
+extern Matrix1D<QList<double>> subgroupsOccupyMaxSetsOfTimeSlotsFromSelectionPercentages;
+extern Matrix1D<QList<int>> subgroupsOccupyMaxSetsOfTimeSlotsFromSelectionMaxOccupiedSets;
+extern Matrix1D<QList<QList<QSet<int>>>> subgroupsOccupyMaxSetsOfTimeSlotsFromSelectionListOfSets;
+extern Matrix1D<QList<QList<QList<int>>>> subgroupsOccupyMaxSetsOfTimeSlotsFromSelectionListOfLists;
+
+bool computeSubgroupsOccupyMaxSetsOfTimeSlotsFromSelection(QWidget* parent);
+//END   students (set) occupy max sets of time slots from selection
+
+
 //BEGIN teacher(s) pair of mutually exclusive time slots
 extern bool haveTeachersPairOfMutualExclusiveTimeSlots;
 
