@@ -1200,6 +1200,12 @@ private:
 	TimeConstraint* readStudentsSetPairOfMutuallyExclusiveSetsOfTimeSlots(QXmlStreamReader& xml, FakeString& xmlReadingLog);
 	TimeConstraint* readStudentsPairOfMutuallyExclusiveSetsOfTimeSlots(QXmlStreamReader& xml, FakeString& xmlReadingLog);
 
+	TimeConstraint* readTeacherOccupiesMaxSetsOfTimeSlotsFromSelection(QXmlStreamReader& xml, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersOccupyMaxSetsOfTimeSlotsFromSelection(QXmlStreamReader& xml, FakeString& xmlReadingLog);
+
+	TimeConstraint* readStudentsSetOccupiesMaxSetsOfTimeSlotsFromSelection(QXmlStreamReader& xml, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsOccupyMaxSetsOfTimeSlotsFromSelection(QXmlStreamReader& xml, FakeString& xmlReadingLog);
+
 	TimeConstraint* readStudentsSetMaxSingleGapsInSelectedTimeSlots(QXmlStreamReader& xml, FakeString& xmlReadingLog);
 	TimeConstraint* readStudentsMaxSingleGapsInSelectedTimeSlots(QXmlStreamReader& xml, FakeString& xmlReadingLog);
 
